@@ -16,7 +16,7 @@ class Similarity(Enum):
     Hamming = 2
     L1 = 3
     L2 = 4
-    Angular = 5
+    Cosine = 5
 
 
 class Vec:
@@ -79,19 +79,6 @@ class Mapping:
                 }
             }
 
-    @dataclass(frozen=True)
-    class SparseIndexed(Base):
-        dims: int
-
-        def to_dict(self):
-            return {
-                "type": "elastiknn_sparse_bool_vector",
-                "elastiknn": {
-                    "dims": self.dims,
-                    "model": "sparse_indexed"
-                }
-            }
-
     @dataclass(frozen=True)
     class JaccardLsh(Base):
         dims: int
@@ -141,7 +128,7 @@ class Mapping:
             }
 
     @dataclass(frozen=True)
-    class AngularLsh(Base):
+    class CosineLsh(Base):
         dims: int
         L: int
         k: int
@@ -151,7 +138,7 @@ class Mapping:
                 "type": "elastiknn_dense_float_vector",
                 "elastiknn": {
                     "model": "lsh",
-                    "similarity": "angular",
+                    "similarity": "cosine",
                     "dims": self.dims,
                     "L": self.L,
                     "k": self.k
@@ -224,23 +211,6 @@ class NearestNeighborsQuery:
         def with_vec(self, vec: Vec.Base):
             return NearestNeighborsQuery.Exact(field=self.field, vec=vec, similarity=self.similarity)
 
-    @dataclass(frozen=True)
-    class SparseIndexed(Base):
-        field: str
-        vec: Vec.Base
-        similarity: Similarity
-
-        def to_dict(self):
-            return {
-                "field": self.field,
-                "model": "sparse_indexed",
-                "similarity": self.similarity.name.lower(),
-                "vec": self.vec.to_dict()
-            }
-
-        def with_vec(self, vec: Vec.Base):
-            return NearestNeighborsQuery.SparseIndexed(field=self.field, vec=vec, similarity=self.similarity)
-
     @dataclass(frozen=True)
     class JaccardLsh(Base):
         field: str
@@ -282,10 +252,10 @@ class NearestNeighborsQuery:
                                                     candidates=self.candidates)
 
     @dataclass(frozen=True)
-    class AngularLsh(Base):
+    class CosineLsh(Base):
         field: str
         vec: Vec.Base
-        similarity: Similarity = Similarity.Angular
+        similarity: Similarity = Similarity.Cosine
         candidates: int = 1000
 
         def to_dict(self):
@@ -298,8 +268,8 @@ class NearestNeighborsQuery:
             }
 
         def with_vec(self, vec: Vec.Base):
-            return NearestNeighborsQuery.AngularLsh(field=self.field, vec=vec, similarity=self.similarity,
-                                                    candidates=self.candidates)
+            return NearestNeighborsQuery.CosineLsh(field=self.field, vec=vec, similarity=self.similarity,
+                                                   candidates=self.candidates)
 
     @dataclass(frozen=True)
     class L2Lsh(Base):
@@ -327,7 +297,7 @@ class NearestNeighborsQuery:
     class PermutationLsh(Base):
         field: str
         vec: Vec.Base
-        similarity: Similarity = Similarity.Angular
+        similarity: Similarity = Similarity.Cosine
         candidates: int = 1000
 
         def to_dict(self):
